Package: mapboxer
Title: An R Interface to 'Mapbox GL JS'
Version: 0.4.0
Date: 2020-10-28
Authors@R: person("Stefan", "Kuethe", email = "crazycapivara@gmail.com", role = c("aut", "cre"))
Maintainer: Stefan Kuethe <crazycapivara@gmail.com>
Description: Makes 'Mapbox GL JS' <https://docs.mapbox.com/mapbox-gl-js/api/>,
  an open source JavaScript library that uses WebGL to render interactive maps,
  available within R via the 'htmlwidgets' package. Visualizations can be used from the R console,
  in R Markdown documents and in Shiny apps.
License: MIT + file LICENSE
Depends: R (>= 2.10)
Imports: magrittr, htmlwidgets, htmltools, yaml, purrr, geojsonsf,
        methods
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
Suggests: knitr, rmarkdown, shiny
VignetteBuilder: knitr
URL: https://github.com/crazycapivara/mapboxer
BugReports: https://github.com/crazycapivara/mapboxer/issues
NeedsCompilation: no
Packaged: 2020-10-28 17:52:19 UTC; gabbo
Author: Stefan Kuethe [aut, cre]
Repository: CRAN
Date/Publication: 2020-11-04 16:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 19:33:21 UTC; unix
