# Generated by roxygen2: do not edit by hand

S3method(as_mapbox_source,data.frame)
S3method(as_mapbox_source,json)
S3method(as_mapbox_source,sf)
S3method(set_data,character)
S3method(set_data,data.frame)
S3method(set_data,json)
S3method(set_data,sf)
export("%<>%")
export("%>%")
export(add_circle_layer)
export(add_control)
export(add_draw_control)
export(add_fill_layer)
export(add_filter_control)
export(add_fullscreen_control)
export(add_layer)
export(add_line_layer)
export(add_marker)
export(add_mouse_position_control)
export(add_navigation_control)
export(add_popups)
export(add_scale_control)
export(add_source)
export(add_text_control)
export(add_tooltips)
export(as_mapbox_source)
export(basemap_background_style)
export(basemap_raster_style)
export(fit_bounds)
export(mapbox_source)
export(mapboxer)
export(mapboxerOutput)
export(mapboxer_proxy)
export(renderMapboxer)
export(set_data)
export(set_filter)
export(set_layout_property)
export(set_paint_property)
export(set_style)
export(set_view_state)
export(stamen_raster_tiles)
export(update_mapboxer)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(methods,getPackageName)
